---
name: "\U0001F914 Question"
about: Usage question that isn't answered in docs or discussion

---

## Question

Before asking a question, make sure you have:

- Reviewed relevant Rust information: Google your error messages and look at official docs.
- Searched open and closed [GitHub issues](https://github.com/tonbo-io/tonbo/issues)
